@@ -20,7 +20,8 @@ class TestVersioningWithI18nExtension(TestCase):
                 'base_classes': (self.Model, )
             }
             __translatable__ = {
-                'base_classes': (Versioned, )
+                'base_classes': (Versioned, ),
+                'locales': ['fi', 'en']
             }
             __translated_columns__ = [
                 sa.Column('name', sa.Unicode(255)),
@@ -58,3 +59,20 @@ class TestVersioningWithI18nExtension(TestCase):
             .first()
         )
         assert 'ArticleTranslation' in tx.entity_names
+
+    def test_history_with_many_translations(self):
+        self.article = self.Article()
+        self.article.description = u'Some text'
+        self.session.add(self.article)
+
+        with self.article.force_locale('fi'):
+            self.article.name = 'Text 1'
+        with self.article.force_locale('en'):
+            self.article.name = 'Text 2'
+
+        self.session.commit()
+
+        TransactionLog = self.Article.__versioned__['transaction_log']
+        transaction = self.session.query(TransactionLog).one()
+
+        assert transaction.changes[1].entity_name == u'ArticleTranslation'
