@@ -1,11 +1,10 @@
 import sqlalchemy as sa
-from sqlalchemy_continuum import Versioned
 from . import TestCase
 
 
 class TestManyToManyRelationships(TestCase):
     def create_models(self):
-        class Article(self.Model, Versioned):
+        class Article(self.Model):
             __tablename__ = 'article'
             __versioned__ = {
                 'base_classes': (self.Model, )
@@ -31,7 +30,7 @@ class TestManyToManyRelationships(TestCase):
             )
         )
 
-        class Tag(self.Model, Versioned):
+        class Tag(self.Model):
             __tablename__ = 'tag'
             __versioned__ = {
                 'base_classes': (self.Model, )
